@@ -30,6 +30,14 @@ class Logger(object):
         """
         return Logger()
 
+    @classmethod
+    def instance(cls):
+        """
+        获取日志实例
+        :return:
+        """
+        return Logger()
+
     @classmethod
     def config(cls,
                log_level=LogLevel.DEBUG,
@@ -53,7 +61,7 @@ class Logger(object):
         :param is_colored:          是否将控制台的输出设为彩色
         :return:
         """
-        print("log file: " + log_file_full_path)
+        # print("log file: " + log_file_full_path)
         cls._logger = cls._get_config_logger("my_logger", is_with_src_info=False, log_level=log_level,
                                              log_file_full_path=log_file_full_path, date_format=date_format,
                                              is_with_datetime=is_with_datetime, is_with_level=is_with_level,
@@ -94,8 +102,8 @@ class Logger(object):
         :param is_colored:          是否将控制台的输出设为彩色
         :return: 返回一个配置完成的logger
         """
-        if log_file_full_path == "all.log" or len(log_file_full_path.strip()) == 0:
-            log_file_full_path = Directory.get_current_directory() + "/all.log"
+        # if log_file_full_path == "all.log" or len(log_file_full_path.strip()) == 0:
+        #     log_file_full_path = Directory.get_current_directory() + "/all.log"
 
         logger = sys_logging.getLogger(logger_name)
         logger.handlers.clear()  # 清空handlers，防止是二次调用config
